@@ -2,7 +2,6 @@
 #this repository contains the full copyright notices and license terms.
 
 from trytond.backend.table import TableHandlerInterface
-from trytond.backend.sqlite.fields import FIELDS
 import logging
 import re
 
@@ -118,23 +117,23 @@ class TableHandler(TableHandlerInterface):
     def alter_size(self, column_name, column_type):
         logging.getLogger('init').warning(
             'Unable to alter size of column %s ' \
-                'of table %s not null!' % \
+                'of table %s!' % \
                 (column_name, self.table_name))
 
     def alter_type(self, column_name, column_type):
         logging.getLogger('init').warning(
             'Unable to alter type of column %s ' \
-                'of table %s not null!' % \
+                'of table %s!' % \
                 (column_name, self.table_name))
 
     def db_default(self, column_name, value):
         logging.getLogger('init').warning(
             'Unable to set default on column %s ' \
-                'of table %s not null!' % \
+                'of table %s!' % \
                 (column_name, self.table_name))
 
     def add_raw_column(self, column_name, column_type, column_format,
-            default_fun=None, field_size=None, migrate=True):
+            default_fun=None, field_size=None, migrate=True, string=''):
         if self.column_exist(column_name):
             if not migrate:
                 return
@@ -160,7 +159,6 @@ class TableHandler(TableHandlerInterface):
                 if field_size == None:
                     if self._columns[column_name]['size'] > 0:
                         self.alter_size(column_name, base_type)
-                    pass
                 elif self._columns[column_name]['size'] == field_size:
                     pass
                 elif self._columns[column_name]['size'] > 0 and \
@@ -268,7 +266,7 @@ class TableHandler(TableHandlerInterface):
             (column_name, self.table_name))
 
     @staticmethod
-    def dropTable(cursor, model, table, cascade=False):
+    def drop_table(cursor, model, table, cascade=False):
         cursor.execute('DELETE from ir_model_data where '\
                            'model = \'%s\'' % model)
 
