@@ -1,7 +1,7 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 import ConfigParser, optparse, os, sys
-from version import VERSION
+from trytond.version import VERSION
 
 
 class ConfigManager(object):
@@ -12,6 +12,9 @@ class ConfigManager(object):
             'netport': 8070,
             'xmlrpc': False,
             'xmlport': 8069,
+            'jsonrpc': False,
+            'jsonport': 8000,
+            'jsondata_path': '/var/www/localhost/tryton',
             'webdav': False,
             'webdavport': 8080,
             'db_type': 'postgresql',
@@ -30,6 +33,7 @@ class ConfigManager(object):
             'logfile': None,
             'secure_netrpc': False,
             'secure_xmlrpc': False,
+            'secure_jsonrpc': False,
             'secure_webdav': False,
             'privatekey': '/etc/ssl/trytond/server.key',
             'certificate': '/etc/ssl/trytond/server.pem',
@@ -48,6 +52,7 @@ class ConfigManager(object):
             'init': {},
             'update': {},
         }
+        self.configfile = None
 
     def parse(self):
         parser = optparse.OptionParser(version=VERSION)
@@ -55,7 +60,7 @@ class ConfigManager(object):
         parser.add_option("-c", "--config", dest="config",
                 help="specify config file")
         parser.add_option('--debug', dest='debug_mode', action='store_true',
-                help='enable debug mode')
+                help='enable debug mode (start post-mortem debugger if exceptions occur)')
         parser.add_option("-v", "--verbose", action="store_true",
                 dest="verbose", help="enable verbose mode")
 
@@ -71,7 +76,7 @@ class ConfigManager(object):
         parser.add_option("--logfile", dest="logfile",
                 help="file where the server log will be stored")
 
-        (opt, args) = parser.parse_args()
+        (opt, _) = parser.parse_args()
 
         if opt.config:
             self.configfile = opt.config
@@ -114,14 +119,14 @@ class ConfigManager(object):
         init = {}
         if opt.init:
             for i in opt.init.split(','):
-                if i != 'tests':
+                if i != 'test':
                     init[i] = 1
         self.options['init'] = init
 
         update = {}
         if opt.update:
             for i in opt.update.split(','):
-                if i != 'tests':
+                if i != 'test':
                     update[i] = 1
         self.options['update'] = update
 
@@ -135,7 +140,7 @@ class ConfigManager(object):
                 value = True
             if value == 'False' or value == 'false':
                 value = False
-            if name in ('netport', 'xmlport', 'webdavport'):
+            if name in ('netport', 'xmlport', 'webdavport', 'jsonport'):
                 value = int(value)
             self.options[name] = value
 
