@@ -2,8 +2,9 @@
 #this repository contains the full copyright notices and license terms.
 "Action"
 from trytond.model import ModelView, ModelSQL, ModelStorage, fields
-from trytond.tools import file_open, Cache
+from trytond.tools import file_open, Cache, safe_eval
 from trytond.backend import TableHandler
+from trytond.pyson import PYSONEncoder, CONTEXT, PYSON
 import base64
 import os
 
@@ -180,6 +181,7 @@ class ActionKeyword(ModelSQL, ModelView):
             ('keyword', '=', keyword),
             ('model', '=', model + ',0'),
             ], context=context))
+        encoder = PYSONEncoder()
         for action_keyword in self.browse(cursor, user, action_keyword_ids,
                 context=context):
             try:
@@ -196,6 +198,10 @@ class ActionKeyword(ModelSQL, ModelView):
                     del res[-1]['report_content_data']
                     del res[-1]['report_content']
                     del res[-1]['style_content']
+                    res[-1]['email'] = encoder.encode(res[-1]['email'])
+                elif action_keyword.action.type == 'ir.action.act_window':
+                    for field in ('domain', 'context', 'search_value'):
+                        del res[-1][field]
         return res
 
 ActionKeyword()
@@ -210,15 +216,14 @@ class ActionReport(ModelSQL, ModelView):
     report_name = fields.Char('Internal Name', required=True)
     report = fields.Char('Path')
     report_content_data = fields.Binary('Content')
-    report_content = fields.Function('get_report_content',
-            fnct_inv='report_content_inv', type='binary',
-            string='Content')
+    report_content = fields.Function(fields.Binary('Content'),
+            'get_report_content', setter='set_report_content')
     action = fields.Many2One('ir.action', 'Action', required=True,
             ondelete='CASCADE')
-    style = fields.Property(type='char', string='Style',
-            help='Define the style to apply on the report.')
-    style_content = fields.Function('get_style_content',
-            type='binary', string='Style')
+    style = fields.Property(fields.Char('Style',
+            help='Define the style to apply on the report.'))
+    style_content = fields.Function(fields.Binary('Style'),
+            'get_style_content')
     direct_print = fields.Boolean('Direct Print')
     extension = fields.Selection(
         [('odt', 'ODT Document'),
@@ -275,7 +280,7 @@ class ActionReport(ModelSQL, ModelView):
     def default_module(self, cursor, user, context=None):
         return context and context.get('module', '') or ''
 
-    def get_report_content(self, cursor, user, ids, name, arg, context=None):
+    def get_report_content(self, cursor, user, ids, name, context=None):
         res = {}
         for report in self.browse(cursor, user, ids, context=context):
             data = report[name + '_data']
@@ -289,11 +294,12 @@ class ActionReport(ModelSQL, ModelView):
             res[report.id] = data
         return res
 
-    def report_content_inv(self, cursor, user, obj_id, name, value, arg,
+    def set_report_content(self, cursor, user, ids, name, value,
             context=None):
-        self.write(cursor, user, obj_id, {name+'_data': value}, context=context)
+        self.write(cursor, user, ids, {'%s_data' % name: value},
+                context=context)
 
-    def get_style_content(self, cursor, user, ids, name, arg, context=None):
+    def get_style_content(self, cursor, user, ids, name, context=None):
         res = {}
         for report in self.browse(cursor, user, ids, context=context):
             try:
@@ -343,6 +349,7 @@ class ActionReport(ModelSQL, ModelView):
         new_id = report.action.id
         cursor.execute('UPDATE "' + self._table + '" SET id = %s ' \
                 'WHERE id = %s', (report.action.id, report.id))
+        cursor.update_auto_increment(self._table, report.action.id)
         ModelStorage.delete(self, cursor, user, report.id)
         self.write(cursor, user, new_id, later, context=context)
         return new_id
@@ -389,8 +396,7 @@ class ActionActWindow(ModelSQL, ModelView):
         ], string='Type of view')
     act_window_views = fields.One2Many('ir.action.act_window.view',
             'act_window', 'Views')
-    views = fields.Function('views_get_fnc', type='binary',
-            string='Views')
+    views = fields.Function(fields.Binary('Views'), 'get_views')
     limit = fields.Integer('Limit',
             help='Default limit for the list view')
     auto_refresh = fields.Integer('Auto-Refresh',
@@ -401,6 +407,24 @@ class ActionActWindow(ModelSQL, ModelView):
             help='Use the action name as window name')
     search_value = fields.Char('Search Criteria',
             help='Default search criteria for the list view')
+    pyson_domain = fields.Function(fields.Char('PySON Domain'), 'get_pyson')
+    pyson_context = fields.Function(fields.Char('PySON Context'),
+            'get_pyson')
+    pyson_search_value = fields.Function(fields.Char(
+        'PySON Search Criteria'), 'get_pyson')
+
+    def __init__(self):
+        super(ActionActWindow, self).__init__()
+        self._constraints += [
+            ('check_domain', 'invalid_domain'),
+            ('check_context', 'invalid_context'),
+            ('check_search_value', 'invalid_search_value'),
+        ]
+        self._error_messages.update({
+            'invalid_domain': 'Invalid domain!',
+            'invalid_context': 'Invalid context!',
+            'invalid_search_value': 'Invalid search criteria!',
+        })
 
     def default_type(self, cursor, user, context=None):
         return 'ir.action.act_window'
@@ -423,13 +447,82 @@ class ActionActWindow(ModelSQL, ModelView):
     def default_search_value(self, cursor, user, context=None):
         return '{}'
 
-    def views_get_fnc(self, cursor, user, ids, name, arg, context=None):
+    def check_domain(self, cursor, user, ids):
+        "Check domain"
+        for action in self.browse(cursor, user, ids):
+            if action.domain:
+                try:
+                    value = safe_eval(action.domain, CONTEXT)
+                except:
+                    return False
+                if isinstance(value, PYSON):
+                    if not value.types() == set([list]):
+                        return False
+                elif not isinstance(value, list):
+                    return False
+                else:
+                    try:
+                        fields.domain_validate(value)
+                    except:
+                        return False
+        return True
+
+    def check_context(self, cursor, user, ids):
+        "Check context"
+        for action in self.browse(cursor, user, ids):
+            if action.context:
+                try:
+                    value = safe_eval(action.context, CONTEXT)
+                except:
+                    return False
+                if isinstance(value, PYSON):
+                    if not value.types() == set([dict]):
+                        return False
+                elif not isinstance(value, dict):
+                    return False
+                else:
+                    try:
+                        fields.context_validate(value)
+                    except:
+                        return False
+        return True
+
+    def check_search_value(self, cursor, user, ids):
+        "Check search_value"
+        for action in self.browse(cursor, user, ids):
+            if action.search_value:
+                try:
+                    value = safe_eval(action.search_value, CONTEXT)
+                except:
+                    return False
+                if isinstance(value, PYSON):
+                    if not value.types() == set([dict]):
+                        return False
+                elif not isinstance(value, dict):
+                    return False
+        return True
+
+    def get_views(self, cursor, user, ids, name, context=None):
         res = {}
         for act in self.browse(cursor, user, ids, context=context):
             res[act.id] = [(view.view.id, view.view.type) \
                     for view in act.act_window_views]
         return res
 
+    def get_pyson(self, cursor, user, ids, name, context=None):
+        res = {}
+        encoder = PYSONEncoder()
+        field = name[6:]
+        defaults = {
+            'domain': '[]',
+            'context': '{}',
+            'search_value': '{}',
+        }
+        for act in self.browse(cursor, user, ids, context=context):
+            res[act.id] = encoder.encode(safe_eval(act[field] or
+                defaults.get(field, 'False'), CONTEXT))
+        return res
+
     def create(self, cursor, user, vals, context=None):
         later = {}
         vals = vals.copy()
@@ -447,6 +540,7 @@ class ActionActWindow(ModelSQL, ModelView):
         new_id = act_window.action.id
         cursor.execute('UPDATE "' + self._table + '" SET id = %s ' \
                 'WHERE id = %s', (act_window.action.id, act_window.id))
+        cursor.update_auto_increment(self._table, act_window.action.id)
         ModelStorage.delete(self, cursor, user, act_window.id)
         self.write(cursor, user, new_id, later, context=context)
         return new_id
@@ -524,6 +618,7 @@ class ActionWizard(ModelSQL, ModelView):
         new_id = wizard.action.id
         cursor.execute('UPDATE "' + self._table + '" SET id = %s ' \
                 'WHERE id = %s', (wizard.action.id, wizard.id))
+        cursor.update_auto_increment(self._table, wizard.action.id)
         ModelStorage.delete(self, cursor, user, wizard.id)
         self.write(cursor, user, new_id, later, context=context)
         return new_id
@@ -613,6 +708,7 @@ class ActionWizardSize(ModelSQL, ModelView):
                 'height': height,
                 }, context=context)
 
+    @Cache('ir.action.wizard_size.get_size')
     def get_size(self, cursor, user, wizard, model, context=None):
         '''
         Get size for wizard dialog.
@@ -633,8 +729,6 @@ class ActionWizardSize(ModelSQL, ModelView):
             return wizard_size.width, wizard_size.height
         return (0, 0)
 
-    get_size = Cache('ir.action.wizard_size.get_size')(get_size)
-
 ActionWizardSize()
 
 
@@ -670,6 +764,7 @@ class ActionURL(ModelSQL, ModelView):
         new_id = url.action.id
         cursor.execute('UPDATE "' + self._table + '" SET id = %s ' \
                 'WHERE id = %s', (url.action.id, url.id))
+        cursor.update_auto_increment(self._table, url.action.id)
         ModelStorage.delete(self, cursor, user, url.id)
         self.write(cursor, user, new_id, later, context=context)
         return new_id
