@@ -3,9 +3,10 @@
 "Default"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.tools import Cache, safe_eval
+from trytond.pyson import Eval
 from decimal import Decimal
-import mx.DateTime
 import datetime
+import time
 
 
 class Default(ModelSQL, ModelView):
@@ -16,7 +17,7 @@ class Default(ModelSQL, ModelView):
     model = fields.Many2One('ir.model', 'Model', required=True,
        ondelete='CASCADE')
     field = fields.Many2One('ir.model.field', 'Field', required=True,
-       ondelete='CASCADE', domain=["('model', '=', model)"])
+       ondelete='CASCADE', domain=[('model', '=', Eval('model'))])
     value = fields.Text('Value')
     clause = fields.Text('Clause')
     user = fields.Many2One('res.user', 'User', ondelete='CASCADE')
@@ -29,6 +30,7 @@ class Default(ModelSQL, ModelView):
             'reset_default': True,
         })
 
+    @Cache('ir_default.get_default')
     def get_default(self, cursor, user, model, clause, context=None):
         res = {}
         test_user = user
@@ -59,21 +61,15 @@ class Default(ModelSQL, ModelView):
                 elif default.field.ttype == 'numeric':
                     res[default.field.name] = Decimal(default.value)
                 elif default.field.ttype == 'date':
-                    date = mx.DateTime.strptime(default.value, '%Y-%m-%d')
-                    res[default.field.name] = datetime.date(date.year,
-                            date.month, date.day)
+                    res[default.field.name] = datetime.date(*time.strptime(
+                        default.value, '%Y-%m-%d')[:3])
                 elif default.field.ttype == 'datetime':
-                    date = mx.DateTime.strptime(default.value,
-                            '%Y-%m-%d %H:%M:%S')
-                    res[default.field.name] = datetime.datetime(date.year,
-                            date.month, date.day, date.hour, date.minute,
-                            int(date.second))
+                    res[default.field.name] = datetime.datetime(*time.strptime(
+                        default.value, '%Y-%m-%d %H:%M:%S')[:6])
                 else:
                     res[default.field.name] = safe_eval(default.value)
         return res
 
-    get_default = Cache('ir_default.get_default')(get_default)
-
     def set_default(self, cursor, user, model, field, clause, value,
             user_default, context=None):
         ir_model_obj = self.pool.get('ir.model')
