@@ -3,8 +3,9 @@
 "Lang"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.model.cacheable import Cacheable
-from trytond.tools import safe_eval
+from trytond.tools import safe_eval, datetime_strftime
 import time
+import datetime
 from time_locale import TIME_LOCALE
 
 
@@ -46,6 +47,15 @@ class Lang(ModelSQL, ModelView, Cacheable):
             'invalid_date': 'The date format is not valid!',
         })
 
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [('code',) + clause[1:]],
+                order=[], context=context)
+        if ids:
+            ids += self.search(cursor, user, [('name',) + clause[1:]],
+                    order=[], context=context)
+            return [('id', 'in', ids)]
+        return [('name',) + clause[1:]]
+
     def read(self, cursor, user, ids, fields_names=None, context=None):
         translation_obj = self.pool.get('ir.translation')
         if context is None:
@@ -114,7 +124,8 @@ class Lang(ModelSQL, ModelView, Cacheable):
         '''
         for lang in self.browse(cursor, user, ids):
             try:
-                time.strftime(lang.date, time.localtime())
+                datetime_strftime(datetime.datetime.now(),
+                        lang.date.encode('utf-8'))
             except:
                 return False
             if '%Y' not in lang.date:
@@ -326,20 +337,23 @@ class Lang(ModelSQL, ModelView, Cacheable):
 
         return s.replace('<', '').replace('>', '')
 
-    def strftime(self, timetuple, code, format):
+    def strftime(self, datetime, code, format):
         '''
-        Convert timetuple to a string as specified by the format argument.
+        Convert datetime to a string as specified by the format argument.
 
-        :param timetuple: a tuple or struct_time representing a time
+        :param datetime: a datetime
         :param code: locale code
         :param format: a string
         :return: a unicode string
         '''
         if code in TIME_LOCALE:
             for f, i in (('%a', 6), ('%A', 6), ('%b', 1), ('%B', 1)):
-                format = format.replace(f, TIME_LOCALE[code][f][timetuple[i]])
+                format = format.replace(f,
+                        TIME_LOCALE[code][f][datetime.timetuple()[i]])
             format = format.replace('%p', TIME_LOCALE[code]['%p']\
-                    [timetuple[3] < 12 and 0 or 1]).encode('utf-8')
-        return time.strftime(format, timetuple).decode('utf-8')
+                    [datetime.timetuple()[3] < 12 and 0 or 1]).encode('utf-8')
+        else:
+            format = format.encode('utf-8')
+        return datetime_strftime(datetime, format).decode('utf-8')
 
 Lang()
