@@ -5,8 +5,10 @@ from trytond.model import ModelView, ModelSQL, fields
 from trytond.tools import Cache
 from trytond.report import Report
 from trytond.wizard import Wizard
-import time
+import datetime
 import base64
+import re
+IDENTIFIER = re.compile(r'^[a-zA-z_][a-zA-Z0-9_]*$')
 
 
 class Model(ModelSQL, ModelView):
@@ -27,8 +29,23 @@ class Model(ModelSQL, ModelView):
             ('model_uniq', 'UNIQUE(model)',
                 'The model must be unique!'),
         ]
+        self._constraints += [
+            ('check_module', 'invalid_module'),
+        ]
+        self._error_messages.update({
+            'invalid_module': 'Module Name must be a python identifier!',
+        })
         self._order.insert(0, ('model', 'ASC'))
 
+    def check_module(self, cursor, user, ids):
+        '''
+        Check module
+        '''
+        for model in self.browse(cursor, user, ids):
+            if model.module and not IDENTIFIER.match(model.module):
+                return False
+        return True
+
 Model()
 
 
@@ -54,6 +71,12 @@ class ModelField(ModelSQL, ModelView):
             ('name_model_uniq', 'UNIQUE(name, model)',
                 'The field name in model must be unique!'),
         ]
+        self._constraints += [
+            ('check_name', 'invalid_name'),
+        ]
+        self._error_messages.update({
+            'invalid_name': 'Model Field Name must be a python identifier!',
+        })
         self._order.insert(0, ('name', 'ASC'))
 
     def default_name(self, cursor, user, context=None):
@@ -62,6 +85,15 @@ class ModelField(ModelSQL, ModelView):
     def default_field_description(self, cursor, user, context=None):
         return 'No description available'
 
+    def check_name(self, cursor, user, ids):
+        '''
+        Check name
+        '''
+        for field in self.browse(cursor, user, ids):
+            if not IDENTIFIER.match(field.name):
+                return False
+        return True
+
     def read(self, cursor, user, ids, fields_names=None, context=None):
         translation_obj = self.pool.get('ir.translation')
 
@@ -182,6 +214,7 @@ class ModelAccess(ModelSQL, ModelView):
     def default_perm_delete(self, cursor, user, context=None):
         return False
 
+    @Cache('ir_model_access.check')
     def check(self, cursor, user, model_name, mode='read',
             raise_exception=True, context=None):
         assert mode in ['read', 'write', 'create', 'delete'], \
@@ -221,8 +254,6 @@ class ModelAccess(ModelSQL, ModelView):
                 return False
         return True
 
-    check = Cache('ir_model_access.check')(check)
-
     # Methods to clean the cache on the Check Method.
     def write(self, cursor, user, ids, vals, context=None):
         res = super(ModelAccess, self).write(cursor, user, ids, vals,
@@ -278,6 +309,7 @@ class ModelData(ModelSQL, ModelView):
     date_init = fields.DateTime('Init Date')
     values = fields.Text('Values')
     inherit = fields.Boolean('Inherit')
+    noupdate = fields.Boolean('No Update')
 
     def __init__(self):
         super(ModelData, self).__init__()
@@ -287,12 +319,15 @@ class ModelData(ModelSQL, ModelView):
         ]
 
     def default_date_init(self, cursor, user, context=None):
-        return time.strftime('%Y-%m-%d %H:%M:%S')
+        return datetime.datetime.now()
 
     def default_inherit(self, cursor, user, context=None):
         return False
 
-    def get_id(self, cursor, user, module, fs_id):
+    def default_noupdate(self, cursor, user, context=None):
+        return False
+
+    def get_id(self, cursor, user, module, fs_id, context=None):
         """
         Return for an fs_id the corresponding db_id.
 
@@ -300,18 +335,20 @@ class ModelData(ModelSQL, ModelView):
         :param user: the user id
         :param module: the module name
         :param fs_id: the id in the xml file
+        :param context: the context
 
         :return: the database id
         """
         ids = self.search(cursor, user, [
             ('module', '=', module),
-            ('fs_is', '=', fs_id),
+            ('fs_id', '=', fs_id),
             ('inherit', '=', False),
-            ])
+            ], limit=1, context=context)
         if not ids:
             raise Exception("Reference to %s not found" % \
                                 ".".join([module,fs_id]))
-        return self.read(cursor, user, ids[0], ['db_id'])['db_id']
+        return self.read(cursor, user, ids[0], ['db_id'],
+                context=context)['db_id']
 
 ModelData()
 
@@ -321,6 +358,8 @@ class PrintModelGraphInit(ModelView):
     _name = 'ir.model.print_model_graph.init'
     _description = __doc__
     level = fields.Integer('Level')
+    filter = fields.Text('Filter', help="Entering a Python "
+            "Regular Expression will exclude matching models from the graph.")
 
     def default_level(self, cursor, user, context=None):
         return 1
@@ -364,6 +403,10 @@ class ModelGraph(Report):
         if context is None:
             context = {}
 
+        if not datas['form']['filter']:
+            filter = None
+        else:
+            filter = re.compile(datas['form']['filter'], re.VERBOSE)
         action_report_ids = action_report_obj.search(cursor, user, [
             ('report_name', '=', self._name)
             ], context=context)
@@ -378,11 +421,24 @@ class ModelGraph(Report):
         graph.set('center', '1')
         graph.set('ratio', 'auto')
         self.fill_graph(cursor, user, models, graph,
-                level=datas['form']['level'], context=context)
+                level=datas['form']['level'], filter=filter, context=context)
         data = graph.create(prog='dot', format='png')
         return ('png', base64.encodestring(data), False, action_report.name)
 
-    def fill_graph(self, cursor, user, models, graph, level=1, context=None):
+    def fill_graph(self, cursor, user, models, graph, level=1, filter=None,
+                context=None):
+        '''
+        Fills a pydot graph with a models structure.
+
+        :param cursor: the database cursor
+        :param user: the user id
+        :param models: a BrowseRecordList of ir.model
+        :param graph: a pydot.Graph
+        :param level: the depth to dive into model reationships
+        :param filter: a compiled regular expression object to filter specific
+            models
+        :param context: the context
+        '''
         import pydot
         model_obj = self.pool.get('ir.model')
 
@@ -402,9 +458,11 @@ class ModelGraph(Report):
                         context=context)
                 if set(sub_models) != set(models):
                     self.fill_graph(cursor, user, sub_models, graph,
-                            level=level - 1, context=context)
+                            level=level - 1, filter=filter, context=context)
 
         for model in models:
+            if filter and re.search(filter, model.model):
+                    continue
             label = '{' + model.model + '\\n'
             if model.fields:
                 label += '|'
