@@ -3,6 +3,7 @@
 "Rule"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.tools import Cache, safe_eval
+from trytond.pyson import Eval, Get
 import time
 
 
@@ -87,8 +88,8 @@ class Rule(ModelSQL, ModelView):
     _rec_name = 'field'
     _description = __doc__
     field = fields.Many2One('ir.model.field', 'Field',
-       domain=["('model', '=', _parent_rule_group.model)"], select=1,
-       required=True)
+       domain=[('model', '=', Get(Eval('_parent_rule_group', {}), 'model'))],
+       select=1, required=True)
     operator = fields.Selection([
        ('=', '='),
        ('<>', '<>'),
@@ -140,6 +141,7 @@ class Rule(ModelSQL, ModelView):
             res.append((i, i))
         return res
 
+    @Cache('ir_rule.domain_get')
     def domain_get(self, cursor, user, model_name, mode='read', context=None):
         if context is None:
             context = {}
@@ -236,8 +238,6 @@ class Rule(ModelSQL, ModelView):
 
         return query, val
 
-    domain_get = Cache('ir_rule.domain_get')(domain_get)
-
     def delete(self, cursor, user, ids, context=None):
         res = super(Rule, self).delete(cursor, user, ids, context=context)
         # Restart the cache on the domain_get method of ir.rule
