@@ -1,9 +1,10 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-import time
 from trytond.model import ModelView, ModelSQL, fields
 from string import Template
 import datetime
+from trytond.tools import datetime_strftime
+from trytond.pyson import In, Eval
 
 
 class SequenceType(ModelSQL, ModelView):
@@ -23,7 +24,7 @@ class Sequence(ModelSQL, ModelView):
     name = fields.Char('Sequence Name', required=True, translate=True)
     code = fields.Selection('code_get', 'Sequence Type', required=True,
             states={
-                'readonly': "context.get('code')",
+                'readonly': In('code', Eval('context', {})),
             })
     active = fields.Boolean('Active')
     prefix = fields.Char('Prefix')
@@ -82,9 +83,9 @@ class Sequence(ModelSQL, ModelView):
         date_obj = self.pool.get('ir.date')
         if not date:
             date = date_obj.today(cursor, user, context=context)
-        year = date.strftime('%Y')
-        month = date.strftime('%m')
-        day = date.strftime('%d')
+        year = datetime_strftime(date, '%Y')
+        month = datetime_strftime(date, '%m')
+        day = datetime_strftime(date, '%d')
         return Template(string or '').substitute(
                 year=year,
                 month=month,
@@ -106,21 +107,23 @@ class Sequence(ModelSQL, ModelView):
         if isinstance(domain, (int, long)):
             domain = [('id', '=', domain)]
 
-        sequence_ids = self.search(cursor, user, domain, limit=1,
+        # bypass rules on sequences
+        if 'user' in context:
+            context = context.copy()
+            del context['user']
+        sequence_ids = self.search(cursor, 0, domain, limit=1,
                 context=context)
         date = context.get('date')
         if sequence_ids:
-            sequence = self.browse(cursor, user, sequence_ids[0],
+            sequence = self.browse(cursor, 0, sequence_ids[0],
                     context=context)
             #Pre-fetch number_next
             number_next = sequence.number_next
-            # Use SQL query to bypass access rules
-            cursor.execute('UPDATE "' + self._table + '" ' \
-                    'SET number_next = number_next + number_increment, ' \
-                        'write_uid = %s, ' \
-                        'write_date = %s ' \
-                    'WHERE id = %s AND active = %s',
-                    (user, datetime.datetime.now(), sequence.id, True))
+
+            self.write(cursor, 0, sequence.id, {
+                    'number_next': number_next + sequence.number_increment,
+                    }, context=context)
+
             if number_next:
                 return self._process(cursor, user, sequence.prefix, date=date,
                         context=context) + \
@@ -146,8 +149,7 @@ class SequenceStrict(Sequence):
     _description = __doc__
 
     def get_id(self, cursor, user, clause, context=None):
-        if cursor.has_lock():
-            cursor.execute('LOCK TABLE "' + self._table + '"')
+        cursor.lock(self._table)
         return super(SequenceStrict, self).get_id(cursor, user, clause,
                 context=context)
 
