@@ -17,6 +17,7 @@ from trytond.wizard import Wizard
 from trytond import tools
 from trytond.tools import file_open, reduce_ids
 from trytond.backend import TableHandler
+from trytond.pyson import PYSONEncoder
 import os
 
 TRANSLATION_TYPE = [
@@ -52,8 +53,8 @@ class Translation(ModelSQL, ModelView, Cacheable):
     value = fields.Text('Translation Value')
     module = fields.Char('Module', readonly=True)
     fuzzy = fields.Boolean('Fuzzy')
-    model = fields.Function('get_model', fnct_search='model_search',
-       type='char', string='Model')
+    model = fields.Function(fields.Char('Model'), 'get_model',
+            searcher='search_model')
 
     def __init__(self):
         super(Translation, self).__init__()
@@ -74,22 +75,17 @@ class Translation(ModelSQL, ModelView, Cacheable):
     def default_fuzzy(self, cursor, user, context=None):
         return False
 
-    def get_model(self, cursor, user, ids, name, arg, context=None):
+    def get_model(self, cursor, user, ids, name, context=None):
         res = {}
         for translation in self.browse(cursor, user, ids, context=context):
             res[translation.id] = translation.name.split(',')[0]
         return res
 
-    def model_search(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            cursor.execute('SELECT id FROM ir_translation ' \
-                    'WHERE split_part(name, \',\', 1) ' + args[i][1] + ' %s',
-                    (args[i][2],))
-            args2.append(('id', 'in', [x[0] for x in cursor.fetchall()]))
-            i += 1
-        return args2
+    def search_model(self, cursor, user, name, clause, context=None):
+        cursor.execute('SELECT id FROM "%s" '
+            'WHERE split_part(name, \',\', 1) %s %%s' %
+            (self._table, clause[1]), (clause[2],))
+        return [('id', 'in', [x[0] for x in cursor.fetchall()])]
 
     def get_language(self, cursor, user, context):
         lang_obj = self.pool.get('ir.lang')
@@ -188,7 +184,7 @@ class Translation(ModelSQL, ModelView, Cacheable):
                     ('name', '=', name),
                     ])
                 if not ids2:
-                    self.create(cursor, user, {
+                    self.create(cursor, 0, {
                         'name': name,
                         'lang': lang,
                         'type': ttype,
@@ -197,7 +193,7 @@ class Translation(ModelSQL, ModelView, Cacheable):
                         'fuzzy': False,
                         })
                 else:
-                    self.write(cursor, user, ids, {
+                    self.write(cursor, 0, ids, {
                         'src': record[field_name],
                         'value': value,
                         'fuzzy': False,
@@ -212,7 +208,7 @@ class Translation(ModelSQL, ModelView, Cacheable):
                 ('res_id', '=', record.id),
                 ])
             if not ids2:
-                self.create(cursor, user, {
+                self.create(cursor, 0, {
                     'name': name,
                     'lang': lang,
                     'type': ttype,
@@ -222,7 +218,7 @@ class Translation(ModelSQL, ModelView, Cacheable):
                     'fuzzy': False,
                     })
             else:
-                self.write(cursor, user, ids2, {
+                self.write(cursor, 0, ids2, {
                     'value': value,
                     'src': record[field_name],
                     'fuzzy': False,
@@ -383,11 +379,11 @@ class Translation(ModelSQL, ModelView, Cacheable):
         model_data_ids = model_data_obj.search(cursor, user, [
             ('module', '=', module),
             ], context=context)
-        fs_id2db_id = {}
+        fs_id2model_data = {}
         for model_data in model_data_obj.browse(cursor, user, model_data_ids,
                 context=context):
-            fs_id2db_id.setdefault(model_data.model, {})
-            fs_id2db_id[model_data.model][model_data.fs_id] = model_data.db_id
+            fs_id2model_data.setdefault(model_data.model, {})
+            fs_id2model_data[model_data.model][model_data.fs_id] = model_data
 
         translation_ids = []
         reader = csv.reader(datas)
@@ -420,10 +416,13 @@ class Translation(ModelSQL, ModelView, Cacheable):
             src = row[3].decode('utf-8')
             value = row[4].decode('utf-8')
             fuzzy = bool(int(row[5]))
+            noupdate = False
 
             model = name.split(',')[0]
-            if model in fs_id2db_id:
-                res_id = fs_id2db_id[model].get(res_id, res_id)
+            if model in fs_id2model_data and res_id in fs_id2model_data[model]:
+                model_data = fs_id2model_data[model][res_id]
+                res_id = model_data.db_id
+                noupdate = model_data.noupdate
 
             try:
                 res_id = int(res_id)
@@ -456,7 +455,7 @@ class Translation(ModelSQL, ModelView, Cacheable):
                     if translation.value != value \
                             or translation.fuzzy != fuzzy:
                         ids2.append(translation.id)
-                if ids2:
+                if ids2 and not noupdate:
                     self.write(cursor, 0, ids2, {
                         'value': value,
                         'fuzzy': fuzzy,
@@ -630,7 +629,10 @@ class ReportTranslationSet(Wizard):
                     continue
 
                 content_io = StringIO.StringIO(content)
-                content_z = zipfile.ZipFile(content_io, mode='r')
+                try:
+                    content_z = zipfile.ZipFile(content_io, mode='r')
+                except BadZipfile:
+                    continue
 
                 content_xml = content_z.read('content.xml')
                 document = dom.minidom.parseString(content_xml)
@@ -884,16 +886,23 @@ class TranslationClean(Wizard):
                             'delete_xml_record',
                             'xml_record_desc',
                             'write_xml_record',
+                            'not_found_in_selection',
+                            'relation_not_found',
+                            'too_many_relations_found',
+                            'xml_id_syntax_error',
+                            'reference_syntax_error',
                             'delete_workflow_record',
                             'domain_validation_record',
                             'required_validation_record',
                             'size_validation_record',
+                            'digits_validation_record',
                             'access_error',
                             'read_error',
                             'write_error',
                             'required_field',
                             'foreign_model_missing',
                             'foreign_model_exist',
+                            'search_function_missing',
                             ):
                         continue
                     if model_name in self.pool.object_name_list():
@@ -1049,8 +1058,10 @@ class TranslationUpdate(Wizard):
         model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
                 context=context)
         res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
-        res['domain'] = res['domain'][:-1] + ',' + \
-                str(('lang', '=', data['form']['lang'])) + res['domain'][-1:]
+        res['pyson_domain'] = PYSONEncoder().encode([
+            ('module', '!=', False),
+            ('lang', '=', data['form']['lang']),
+        ])
         return res
 
     states = {
