@@ -15,13 +15,15 @@ class Char(Field):
             change_default=False, translate=False, select=0, on_change=None,
             on_change_with=None, depends=None, order_field=None, context=None):
         '''
+        :param translate: A boolean. If ``True`` the field is translatable.
         :param size: A integer. If set defines the maximum size of the values.
         '''
         super(Char, self).__init__(string=string, help=help, required=required,
                 readonly=readonly, domain=domain, states=states,
                 priority=priority, change_default=change_default,
-                translate=translate, select=select, on_change=on_change,
+                select=select, on_change=on_change,
                 on_change_with=on_change_with, depends=depends,
                 order_field=order_field, context=context)
+        self.translate = translate
         self.size = size
     __init__.__doc__ += Field.__init__.__doc__
