@@ -6,20 +6,20 @@ from trytond.model.fields.field import Field
 
 class Date(Field):
     '''
-    Define a date field (``date``)
+    Define a date field (``date``).
     '''
     _type = 'date'
 
 
 class DateTime(Field):
     '''
-    Define a datetime field (``datetime``)
+    Define a datetime field (``datetime``).
     '''
     _type = 'datetime'
 
 
 class Time(Field):
     '''
-    Define a time field (``time``)
+    Define a time field (``time``).
     '''
     _type = 'time'
