@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 
 from trytond.model.fields.field import Field
+from itertools import chain
 
 
 class Many2Many(Field):
@@ -13,8 +14,8 @@ class Many2Many(Field):
     def __init__(self, relation_name, origin, target, string='', order=None,
             datetime_field=None, help='', required=False, readonly=False,
             domain=None, states=None, priority=0, change_default=False,
-            translate=False, select=0, on_change=None, on_change_with=None,
-            depends=None, order_field=None, context=None):
+            select=0, on_change=None, on_change_with=None, depends=None,
+            order_field=None, context=None):
         '''
         :param relation_name: The name of the relation model
             or the name of the target model for ModelView only.
@@ -33,10 +34,10 @@ class Many2Many(Field):
                 depends = [datetime_field]
         super(Many2Many, self).__init__(string=string, help=help,
                 required=required, readonly=readonly, domain=domain,
-                states=states, priority=priority, change_default=change_default,
-                translate=translate, select=select, on_change=on_change,
-                on_change_with=on_change_with, depends=depends,
-                order_field=order_field, context=context)
+                states=states, priority=priority,
+                change_default=change_default, select=select,
+                on_change=on_change, on_change_with=on_change_with,
+                depends=depends, order_field=order_field, context=context)
         self.relation_name = relation_name
         self.origin = origin
         self.target = target
@@ -70,23 +71,24 @@ class Many2Many(Field):
         relation_ids = []
         for i in range(0, len(ids), cursor.IN_MAX):
             sub_ids = ids[i:i + cursor.IN_MAX]
-            relation_ids += relation_obj.search(cursor, user, [
+            relation_ids.append(relation_obj.search(cursor, user, [
                 (self.origin, 'in', sub_ids),
                 (self.target + '.id', '!=', False),
-                ], order=self.order, context=context)
+                ], order=self.order, context=context))
+        relation_ids = list(chain(*relation_ids))
 
         for relation in relation_obj.read(cursor, user, relation_ids,
                 [self.origin, self.target], context=context):
             res[relation[self.origin]].append(relation[self.target])
         return res
 
-    def set(self, cursor, user, record_id, model, name, values, context=None):
+    def set(self, cursor, user, ids, model, name, values, context=None):
         '''
         Set the values.
 
         :param cursor: The database cursor
         :param user: The user id
-        :param record_id: The record id
+        :param ids: A list of ids
         :param model: A string with the name of the model
         :param name: A string with the name of the field
         :param values: A list of tuples:
@@ -105,74 +107,77 @@ class Many2Many(Field):
         target_obj = self.get_target(model.pool)
         for act in values:
             if act[0] == 'create':
-                relation_obj.create(cursor, user, {
-                    self.origin: record_id,
-                    self.target: [('create', act[1])],
-                    }, context=context)
+                for record_id in ids:
+                    relation_obj.create(cursor, user, {
+                        self.origin: record_id,
+                        self.target: target_obj.create(cursor, user, act[1],
+                            context=context),
+                        }, context=context)
             elif act[0] == 'write':
                 target_obj.write(cursor, user, act[1] , act[2], context=context)
             elif act[0] == 'delete':
                 target_obj.delete(cursor, user, act[1], context=context)
             elif act[0] == 'unlink':
                 if isinstance(act[1], (int, long)):
-                    ids = [act[1]]
+                    target_ids = [act[1]]
                 else:
-                    ids = list(act[1])
-                if not ids:
+                    target_ids = list(act[1])
+                if not target_ids:
                     continue
                 relation_ids = []
-                for i in range(0, len(ids), cursor.IN_MAX):
-                    sub_ids = ids[i:i + cursor.IN_MAX]
+                for i in range(0, len(target_ids), cursor.IN_MAX):
+                    sub_ids = target_ids[i:i + cursor.IN_MAX]
                     relation_ids += relation_obj.search(cursor, user, [
-                        (self.origin, '=', record_id),
+                        (self.origin, 'in', ids),
                         (self.target, 'in', sub_ids),
                         ], context=context)
                 relation_obj.delete(cursor, user, relation_ids, context=context)
             elif act[0] == 'add':
                 if isinstance(act[1], (int, long)):
-                    ids = [act[1]]
+                    target_ids = [act[1]]
                 else:
-                    ids = list(act[1])
-                if not ids:
+                    target_ids = list(act[1])
+                if not target_ids:
                     continue
                 existing_ids = []
-                for i in range(0, len(ids), cursor.IN_MAX):
-                    sub_ids = ids[i:i + cursor.IN_MAX]
+                for i in range(0, len(target_ids), cursor.IN_MAX):
+                    sub_ids = target_ids[i:i + cursor.IN_MAX]
                     relation_ids = relation_obj.search(cursor, user, [
-                        (self.origin, '=', record_id),
+                        (self.origin, 'in', ids),
                         (self.target, 'in', sub_ids),
                         ], context=context)
                     for relation in relation_obj.browse(cursor, user,
                             relation_ids, context=context):
                         existing_ids.append(relation[self.target].id)
-                new_ids = [x for x in ids if x not in existing_ids]
-                for new_id in new_ids:
-                    relation_obj.create(cursor, user, {
-                        self.origin: record_id,
-                        self.target: new_id,
-                        }, context=context)
+                for new_id in (x for x in target_ids if x not in existing_ids):
+                    for record_id in ids:
+                        relation_obj.create(cursor, user, {
+                            self.origin: record_id,
+                            self.target: new_id,
+                            }, context=context)
             elif act[0] == 'unlink_all':
-                ids = relation_obj.search(cursor, user, [
-                    (self.origin, '=', record_id),
+                target_ids = relation_obj.search(cursor, user, [
+                    (self.origin, 'in', ids),
                     (self.target + '.id', '!=', False),
                     ], context=context)
-                relation_obj.delete(cursor, user, ids, context=context)
+                relation_obj.delete(cursor, user, target_ids, context=context)
             elif act[0] == 'set':
                 if not act[1]:
-                    ids = []
+                    target_ids = []
                 else:
-                    ids = list(act[1])
-                ids2 = relation_obj.search(cursor, user, [
-                    (self.origin, '=', record_id),
+                    target_ids = list(act[1])
+                target_ids2 = relation_obj.search(cursor, user, [
+                    (self.origin, 'in', ids),
                     (self.target + '.id', '!=', False),
                     ], context=context)
-                relation_obj.delete(cursor, user, ids2, context=context)
+                relation_obj.delete(cursor, user, target_ids2, context=context)
 
-                for new_id in ids:
-                    relation_obj.create(cursor, user, {
-                        self.origin: record_id,
-                        self.target: new_id,
-                        }, context=context)
+                for new_id in target_ids:
+                    for record_id in ids:
+                        relation_obj.create(cursor, user, {
+                            self.origin: record_id,
+                            self.target: new_id,
+                            }, context=context)
             else:
                 raise Exception('Bad arguments')
 
