@@ -1,6 +1,7 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 
+import copy
 from trytond.model.fields.function import Function
 from trytond.model.fields.field import Field
 from trytond import backend
@@ -11,31 +12,17 @@ class Property(Function):
     Define a property field that is stored in ir.property (any).
     '''
 
-    def __init__(self, type='float', model_name=None, selection=None,
-            digits=None, relation=None, add_remove=None, string='', help='',
-            required=False, readonly=False, domain=None, states=None, priority=0,
-            change_default=False, translate=False, select=0, on_change=None,
-            on_change_with=None, depends=None, order_field=None, context=None):
+    def __init__(self, field):
         '''
-        :param type: The type of the field.
-        :param fnct_search: The name of the search function.
-        :param model_name: See Many2One.
-        :param selection: See Selection.
-        :param digits: See Float.
-        :param relation: Like model_name.
-        :param add_remove: See Many2One.
+        :param field: The field of the function.
         '''
-        super(Property, self).__init__('', type=type, model_name=model_name,
-                selection=selection, digits=digits, relation=relation,
-                add_remove=add_remove, string=string, help=help,
-                required=required, readonly=readonly, domain=domain,
-                states=states, priority=priority, change_default=change_default,
-                translate=translate, select=select, on_change=on_change,
-                on_change_with=on_change_with, depends=depends,
-                order_field=order_field, context=context)
-        self.readonly = False
+        super(Property, self).__init__(field, True, True, True)
+
     __init__.__doc__ += Field.__init__.__doc__
 
+    def __copy__(self):
+        return Property(copy.copy(self._field))
+
     def get(self, cursor, user, ids, model, name, values=None, context=None):
         '''
         Retreive the property.
@@ -55,30 +42,30 @@ class Property(Function):
         return res
 
 
-    def set(self, cursor, user, record_id, model, name, value, context=None):
+    def set(self, cursor, user, ids, model, name, value, context=None):
         '''
         Set the property.
 
         :param cursor: The database cursor.
         :param user: The user id.
-        :param record_id: The record id.
+        :param ids: A list of ids.
         :param model: The model.
         :param name: The name of the field.
         :param value: The value to set.
         :param context: The context.
         '''
         property_obj = model.pool.get('ir.property')
-        return property_obj.set(cursor, user, name, model._name, record_id,
-                (value and (self.model_name or '')  + ',' + str(value)) or False,
-                context=context)
+        return property_obj.set(cursor, user, name, model._name, ids,
+                (value and getattr(self, 'model_name', '')  + ',' + str(value)) or
+                False, context=context)
 
 
-    def search(self, cursor, user, model, name, args, context=None):
+    def search(self, cursor, user, model, name, clause, context=None):
         '''
         :param cursor: The database cursor.
         :param user: The user id.
         :param model: The model.
-        :param args: The search domain. See ModelStorage.search
+        :param clause: The search domain clause. See ModelStorage.search
         :param context: The context.
         :return: New list of domain.
         '''
@@ -95,40 +82,40 @@ class Property(Function):
             return []
         sql_type = sql_type[0]
 
-
-        conditions = "AND ".join(
-            self.get_condition(sql_type, arg) for arg in args)
-        cond_args = self.get_condition_args(args)
-
-
         property_query, property_val = rule_obj.domain_get(
             cursor, user, 'ir.property', context=context)
 
         #Fetch res ids that comply with the domain
         cursor.execute(
-            'SELECT cast(split_part("' + property_obj._table + '".res,\',\',2) as integer), ' + \
+            'SELECT CAST(' \
+                    'SPLIT_PART("' + property_obj._table + '".res,\',\',2) ' \
+                    'AS INTEGER), '\
                 '"' + property_obj._table + '".id '\
             'FROM "' + property_obj._table + '" '\
-                'JOIN "' + field_obj._table + '" on ("' + field_obj._table + '"'+ \
-                      '.id = "' + property_obj._table + '".field) '\
-                'JOIN "' + model_obj._table +'" on ("' + model_obj._table + \
-                      '".id = "' + field_obj._table + '".model) '\
+                'JOIN "' + field_obj._table + '" ON ' \
+                    '("' + field_obj._table + '"'+ \
+                        '.id = "' + property_obj._table + '".field) '\
+                'JOIN "' + model_obj._table +'" ON ' \
+                    '("' + model_obj._table + \
+                        '".id = "' + field_obj._table + '".model) '\
             'WHERE '\
               'CASE WHEN "' +\
-                model_obj._table + '".model = %s AND "' + field_obj._table + '".name = %s AND ' \
+                model_obj._table + '".model = %s ' \
+                'AND "' + field_obj._table + '".name = %s AND ' \
                 + property_query + \
               ' THEN '  + \
-                conditions + \
+                self.get_condition(sql_type, clause) + \
               ' ELSE '\
                 'FALSE '\
               'END',
-            [model._name, name] + property_val + cond_args)
+            [model._name, name] + property_val + \
+                    self.get_condition_args(clause))
 
         props = cursor.fetchall()
         default = None
-        for x in props:
-            if not x[0]:
-                default = x[1]
+        for prop in props:
+            if not prop[0]:
+                default = prop[1]
                 break
 
         if not default:
@@ -158,22 +145,22 @@ class Property(Function):
             return [('id', 'in', res_ids)]
 
     @staticmethod
-    def get_condition(sql_type, arg):
-        if arg[1] in ('in', 'not in'):
+    def get_condition(sql_type, clause):
+        if clause[1] in ('in', 'not in'):
             return ("(cast(split_part(value,',',2) as %s) %s ("+ \
-                ",".join(('%%s',) * len(arg[2])) + ")) ") % (sql_type, arg[1])
+                ",".join(('%%s',) * len(clause[2])) + ")) ") % \
+                (sql_type, clause[1])
         else:
             return "(cast(split_part(value,',',2) as %s) %s %%s) " % \
-                (sql_type, arg[1])
+                (sql_type, clause[1])
 
     @staticmethod
-    def get_condition_args(args):
+    def get_condition_args(clause):
         res = []
-        for arg in args:
-            if arg[1] in ('in', 'not in'):
-                res.extend(arg[2])
-            else:
-                res.append(arg[2])
+        if clause[1] in ('in', 'not in'):
+            res.extend(clause[2])
+        else:
+            res.append(clause[2])
         return res
 
 
