@@ -3,6 +3,7 @@
 from trytond.model import Model
 from trytond.tools import Cache, safe_eval
 from trytond.modules import create_graph, get_module_list
+from trytond.pyson import PYSONEncoder, CONTEXT
 from lxml import etree
 try:
     import hashlib
@@ -24,15 +25,17 @@ def _inherit_apply(src, inherit):
     tree_inherit = etree.fromstring(inherit)
     root_inherit = tree_inherit.getroottree().getroot()
     for element2 in root_inherit:
+        if element2.tag != 'xpath':
+            continue
         element = _find(tree_src, element2)
         if element is not None:
             pos = element2.get('position', 'inside')
             if pos == 'replace':
                 parent = element.getparent()
-                next = element.getnext()
-                if next is not None:
+                enext = element.getnext()
+                if enext is not None:
                     for child in element2:
-                        index = parent.index(next)
+                        index = parent.index(enext)
                         parent.insert(index, child)
                 else:
                     parent.extend(element2.getchildren())
@@ -45,10 +48,10 @@ def _inherit_apply(src, inherit):
                 element.extend(element2.getchildren())
             elif pos == 'after':
                 parent = element.getparent()
-                next = element.getnext()
-                if next is not None:
+                enext = element.getnext()
+                if enext is not None:
                     for child in element2:
-                        index = parent.index(next)
+                        index = parent.index(enext)
                         parent.insert(index, child)
                 else:
                     parent.extend(element2.getchildren())
@@ -90,6 +93,7 @@ class ModelView(Model):
         super(ModelView, self).__init__()
         self._rpc['fields_view_get'] = False
 
+    @Cache('modelview.fields_view_get')
     def fields_view_get(self, cursor, user, view_id=None, view_type='form',
             context=None, toolbar=False, hexmd5=None):
         '''
@@ -247,8 +251,6 @@ class ModelView(Model):
             return True
         return result
 
-    fields_view_get = Cache('modelview.fields_view_get')(fields_view_get)
-
     def view_header_get(self, cursor, user, value, view_type='form',
             context=None):
         """
@@ -374,6 +376,14 @@ class ModelView(Model):
             if element.get('name') in fields_width:
                 element.set('width', str(fields_width[element.get('name')]))
 
+        # convert attributes into pyson
+        encoder = PYSONEncoder()
+        for attr in ('states', 'domain', 'context', 'digits', 'add_remove',
+                'spell', 'colors'):
+            if element.get(attr):
+                element.set(attr, encoder.encode(safe_eval(element.get(attr),
+                    CONTEXT)))
+
         # translate view
         if ('language' in context) and not result:
             for attr in ('string', 'sum', 'confirm', 'help'):
