@@ -16,6 +16,7 @@ class Pool(object):
     _locks = {}
     _pool = {}
     _pools = {}
+    test = False
 
     def __new__(cls, database_name):
         cls._lock.acquire()
@@ -42,17 +43,19 @@ class Pool(object):
         lock.release()
 
     @staticmethod
-    def register(cls, type='model'):
+    def register(klass, type='model'):
         '''
         Register a class
 
-        :param cls: the class
+        :param klass: the class
         :param type: the type
         '''
-        for module in cls.__module__.split('.'):
+        module = None
+        for module in klass.__module__.split('.'):
             if module != 'trytond' and module != 'modules':
                 break
-        Pool.classes[type].setdefault(module, []).append(cls)
+        if module:
+            Pool.classes[type].setdefault(module, []).append(klass)
 
     @staticmethod
     def start():
@@ -62,15 +65,19 @@ class Pool(object):
         Pool._lock.acquire()
         try:
             reload_p = False
+            prev_classes = {}
             for type in Pool.classes:
                 if Pool.classes[type]:
                     reload_p = True
+                prev_classes[type] = Pool.classes[type]
                 Pool.classes[type] = {}
             try:
                 register_classes(reload_p=reload_p)
             except:
                 if not reload_p:
                     raise
+                for type in prev_classes:
+                    Pool.classes[type] = prev_classes[type]
             for db_name in Pool.database_list():
                 Pool(db_name).init()
         finally:
