@@ -14,11 +14,10 @@ import socket
 import os
 import BaseHTTPServer
 import urlparse
-import base64
 import time
 from DAV import AuthServer, WebDAVServer, iface
 from DAV.errors import *
-from DAV.constants import COLLECTION, OBJECT, DAV_VERSION_1, DAV_VERSION_2
+from DAV.constants import COLLECTION, DAV_VERSION_1, DAV_VERSION_2
 from DAV.utils import get_uriparentpath, get_urifilename, quote_uri
 from DAV.davcmd import copyone, copytree, moveone, movetree, delone, deltree
 import urllib
@@ -36,6 +35,7 @@ DAV_VERSION_2['version'] += ',access-control'
 class LocalInt(local):
 
     def __init__(self, value=0):
+        super(LocalInt, self).__init__()
         self.value = value
 
     def __int__(self):
@@ -153,7 +153,8 @@ class TrytonDAVInterface(iface.dav_interface):
             protocol = 'https'
         else:
             protocol = 'http'
-        self.baseuri = '%s://%s:%s/' % (protocol, interface or socket.gethostname(), port)
+        self.baseuri = '%s://%s:%s/' % (protocol, interface or
+                socket.gethostname(), port)
         self.verbose = False
 
     def _log_exception(self, exception):
@@ -218,13 +219,15 @@ class TrytonDAVInterface(iface.dav_interface):
             raise DAV_Error(500)
         return res
 
-    def get_data(self, uri):
+    def get_data(self, uri, range=None):
         dbname, dburi = self._get_dburi(uri)
         if not dbname or (self.exists(uri) and self.is_collection(uri)):
-            res = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">'
+            res = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 '\
+                    'Transitional//EN">'
             res += '<html>'
             res += '<head>'
-            res += '<meta http-equiv="Content-Type" content="text/html; charset=utf-8">'
+            res += '<meta http-equiv="Content-Type" content="text/html; '\
+                    'charset=utf-8">'
             res += '<title>%s - WebDAV - %s</title>' \
                     % (PACKAGE, dbname or 'root')
             res += '</head>'
@@ -258,7 +261,22 @@ class TrytonDAVInterface(iface.dav_interface):
         except Exception, exception:
             self._log_exception(exception)
             raise DAV_Error(500)
-        return res
+        if range is None:
+            return res
+        size = len(res)
+        if range[1] == '':
+            range[1] = size
+        else:
+            range[1] = int(range[1])
+        if range[1] > size:
+            range[1] = size
+        if range[0] == '':
+            range[0] = size - range[1]
+        else:
+            range[0] = int(range[0])
+        if range[0] > size:
+            raise DAV_Requested_Range_Not_Satisfiable
+        return res[range[0]:range[1]]
 
     def put(self, uri, data, content_type=''):
         dbname, dburi = self._get_dburi(uri)
@@ -325,7 +343,24 @@ class TrytonDAVInterface(iface.dav_interface):
         return res
 
     def _get_dav_displayname(self, uri):
-        return uri.split('/')[-1]
+        dbname, dburi = self._get_dburi(uri)
+        if not dbname or not dburi:
+            return uri.split('/')[-1]
+        cursor = DATABASE['cursor']
+        pool = Pool(DATABASE['dbname'])
+        try:
+            collection_obj = pool.get('webdav.collection')
+            res = collection_obj.get_displayname(cursor, int(USER_ID), dburi,
+                    cache=CACHE)
+        except KeyError:
+            raise DAV_NotFound
+        except (DAV_Error, DAV_NotFound, DAV_Secret, DAV_Forbidden), exception:
+            self._log_exception(exception)
+            raise
+        except Exception, exception:
+            self._log_exception(exception)
+            raise DAV_Error(500)
+        return res
 
     def _get_dav_getcontentlength(self, uri):
         dbname, dburi = self._get_dburi(uri)
@@ -444,7 +479,8 @@ class TrytonDAVInterface(iface.dav_interface):
         pool = Pool(DATABASE['dbname'])
         collection_obj = pool.get('webdav.collection')
         try:
-            res = collection_obj.exists(cursor, int(USER_ID), dburi, cache=CACHE)
+            res = collection_obj.exists(cursor, int(USER_ID), dburi,
+                    cache=CACHE)
         except (DAV_Error, DAV_NotFound, DAV_Secret, DAV_Forbidden), exception:
             self._log_exception(exception)
             raise
@@ -486,34 +522,53 @@ class TrytonDAVInterface(iface.dav_interface):
         return self.mkcol(dst)
 
     def _get_dav_current_user_privilege_set(self, uri):
+        dbname, dburi = self._get_dburi(uri)
+        privileges = []
+        if not dbname or not dburi:
+            privileges = ['create', 'read', 'write', 'delete']
+        else:
+            cursor = DATABASE['cursor']
+            pool = Pool(DATABASE['dbname'])
+            try:
+                collection_obj = pool.get('webdav.collection')
+                privileges = collection_obj.current_user_privilege_set(
+                        cursor, int(USER_ID), dburi, cache=CACHE)
+            except KeyError:
+                pass
+            except Exception, exception:
+                self._log_exception(exception)
+                pass
         doc = domimpl.createDocument(None, 'privilege', None)
         privilege = doc.documentElement
         privilege.tagName = 'D:privilege'
-        read = doc.createElement('D:read')
-        privilege.appendChild(read)
-        write = doc.createElement('D:write')
-        privilege.appendChild(write)
-        bind = doc.createElement('D:bind')
-        privilege.appendChild(bind)
-        unbind = doc.createElement('D:unbind')
-        privilege.appendChild(unbind)
-        write_content = doc.createElement('D:write-content')
-        privilege.appendChild(write_content)
-        write_properties = doc.createElement('D:write-properties')
-        privilege.appendChild(write_properties)
-        read_acl = doc.createElement('D:read-acl')
-        privilege.appendChild(read_acl)
+        if 'create' in privileges:
+            bind = doc.createElement('D:bind')
+            privilege.appendChild(bind)
+        if 'read' in privileges:
+            read = doc.createElement('D:read')
+            privilege.appendChild(read)
+            read_acl = doc.createElement('D:read-acl')
+            privilege.appendChild(read_acl)
+        if 'write' in privileges:
+            write = doc.createElement('D:write')
+            privilege.appendChild(write)
+            write_content = doc.createElement('D:write-content')
+            privilege.appendChild(write_content)
+            write_properties = doc.createElement('D:write-properties')
+            privilege.appendChild(write_properties)
+        if 'delete' in privileges:
+            unbind = doc.createElement('D:unbind')
+            privilege.appendChild(unbind)
         return privilege
 
-TrytonDAVInterface.PROPS['DAV:'] = tuple(list(TrytonDAVInterface.PROPS['DAV:']) \
-        + ['current-user-privilege-set'])
+TrytonDAVInterface.PROPS['DAV:'] = tuple(list(TrytonDAVInterface.PROPS['DAV:']
+    ) + ['current-user-privilege-set'])
 
 
 class WebDAVAuthRequestHandler(AuthServer.BufferedAuthRequestHandler,
         WebDAVServer.DAVRequestHandler):
 
     def finish(self):
-        global DATABASE
         dbname = None
         if 'dbname' in DATABASE:
             dbname = DATABASE['dbname']
@@ -527,9 +582,6 @@ class WebDAVAuthRequestHandler(AuthServer.BufferedAuthRequestHandler,
             Cache.resets(dbname)
 
     def get_userinfo(self, user, password, command=''):
-        global USER_ID
-        global DATABASE
-
         dbname = urllib.unquote_plus(self.path.split('/', 2)[1])
         DATABASE['dbname'] = dbname
         if not dbname:
