@@ -4,7 +4,6 @@
 import copy
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
-from lxml import etree
 from trytond.tools import Cache, safe_eval
 from trytond.backend import TableHandler
 from trytond.security import get_connections
@@ -15,6 +14,7 @@ try:
 except ImportError:
     hashlib = None
     import sha
+from trytond.pyson import Eval, Greater
 
 
 class User(ModelSQL, ModelView):
@@ -27,7 +27,9 @@ class User(ModelSQL, ModelView):
     salt = fields.Char('Salt', size=8)
     signature = fields.Text('Signature')
     active = fields.Boolean('Active')
-    action = fields.Many2One('ir.action', 'Home Action')
+    action = fields.Many2One('ir.action', 'Home Action', states={
+        'required': Greater(Eval('active_id', 0), 0),
+        })
     menu = fields.Many2One('ir.action', 'Menu Action',
             domain=[('usage','=','menu')], required=True)
     groups = fields.Many2Many('res.user-res.group',
@@ -37,15 +39,14 @@ class User(ModelSQL, ModelView):
        domain=[('global_p', '!=', True), ('default_p', '!=', True)])
     language = fields.Many2One('ir.lang', 'Language',
             domain=['OR', ('translatable', '=', True), ('code', '=', 'en_US')])
-    language_direction = fields.Function('get_language_direction', type='char',
-            string='Language Direction')
+    language_direction = fields.Function(fields.Char('Language Direction'),
+            'get_language_direction')
     timezone = fields.Selection('timezones', 'Timezone')
     email = fields.Char('Email')
-    status_bar = fields.Function('get_status_bar', type='char',
-            string="Status Bar")
+    status_bar = fields.Function(fields.Char('Status Bar'), 'get_status_bar')
     warnings = fields.One2Many('res.user.warning', 'user', 'Warnings')
-    connections = fields.Function('get_connections', type='integer',
-            string='Connections')
+    connections = fields.Function(fields.Integer('Connections'),
+            'get_connections')
 
     def __init__(self):
         super(User, self).__init__()
@@ -100,7 +101,7 @@ class User(ModelSQL, ModelView):
     def default_action(self, cursor, user, context=None):
         return self.default_menu(cursor, user, context=context)
 
-    def get_language_direction(self, cursor, user, ids, name, arg, context=None):
+    def get_language_direction(self, cursor, user, ids, name, context=None):
         res = {}
         lang_obj = self.pool.get('ir.lang')
         default_direction = lang_obj.default_direction(cursor, user, context=context)
@@ -111,13 +112,13 @@ class User(ModelSQL, ModelView):
                 res[user.id] = default_direction
         return res
 
-    def get_status_bar(self, cursor, user_id, ids, name, arg, context=None):
+    def get_status_bar(self, cursor, user_id, ids, name, context=None):
         res = {}
         for user in self.browse(cursor, user_id, ids, context=context):
             res[user.id] = user.name
         return res
 
-    def get_connections(self, cursor, user, ids, name, arg, context=None):
+    def get_connections(self, cursor, user, ids, name, context=None):
         res = {}
         for user_id in ids:
             res[user_id] = get_connections(cursor.database_name, user_id)
@@ -191,19 +192,13 @@ class User(ModelSQL, ModelView):
                     val['password'] = 'x' * 10
         return res
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [
-                ('login', '=', args[i][2]),
-                ], context=context)
-            if len(ids) == 1:
-                args2.append(('id', '=', ids[0]))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [
+            ('login', '=', clause[2]),
+            ], order=[], context=context)
+        if len(ids) == 1:
+            return [('id', '=', ids[0])]
+        return [(self._rec_name,) + clause[1:]]
 
     def copy(self, cursor, user, ids, default=None, context=None):
         if default is None:
@@ -263,14 +258,13 @@ class User(ModelSQL, ModelView):
             }
         return res
 
+    @Cache('res_user.get_preferences')
     def get_preferences(self, cursor, user_id, context_only=False, context=None):
         user = self.browse(cursor, 0, user_id, context=context)
         res = self._get_preferences(cursor, user_id, user,
                 context_only=context_only, context=context)
         return res
 
-    get_preferences = Cache('res_user.get_preferences')(get_preferences)
-
     def set_preferences(self, cursor, user_id, values, old_password=False,
             context=None):
         '''
@@ -311,14 +305,9 @@ class User(ModelSQL, ModelView):
         if context is None:
             context = {}
 
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'user_view_form_preferences'),
-            ('module', '=', 'res'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = self.fields_view_get(cursor, user, view_id=model_data.db_id,
+        view_id = model_data_obj.get_id(cursor, user, 'res',
+                'user_view_form_preferences')
+        res = self.fields_view_get(cursor, user, view_id=view_id,
                 context=context)
         res = copy.deepcopy(res)
         for field in res['fields']:
@@ -349,6 +338,7 @@ class User(ModelSQL, ModelView):
             res = []
         return res
 
+    @Cache('res_user.get_groups')
     def get_groups(self, cursor, user, context=None):
         '''
         Return a list of group ids for the user
@@ -361,8 +351,7 @@ class User(ModelSQL, ModelView):
         return self.read(cursor, user, user, ['groups'],
                 context=context)['groups']
 
-    get_groups = Cache('res_user.get_groups')(get_groups)
-
+    @Cache('res_user._get_login')
     def _get_login(self, cursor, user, login, context=None):
         cursor.execute('SELECT id, password, salt ' \
                 'FROM "' + self._table + '" '
@@ -371,7 +360,6 @@ class User(ModelSQL, ModelView):
         if not res:
             return None, None, None
         return res
-    _get_login = Cache('res_user._get_login')(_get_login)
 
     def get_login(self, cursor, user, login, password, context=None):
         '''
