@@ -4,19 +4,10 @@
 %prog [options]
 """
 import logging
-format='[%(asctime)s] %(levelname)s:%(name)s:%(message)s'
-datefmt='%a %b %d %H:%M:%S %Y'
-logging.basicConfig(level=logging.DEBUG, format=format, datefmt=datefmt)
 import logging.handlers
 import sys, os, signal
 import time
-from config import CONFIG
-import mx.DateTime
-
-if not hasattr(mx.DateTime, 'strptime'):
-    mx.DateTime.strptime = lambda x, y: mx.DateTime.mktime(
-            time.strptime(x, y))
-
+from trytond.config import CONFIG
 from getpass import getpass
 try:
     import hashlib
@@ -31,8 +22,12 @@ import random
 class TrytonServer(object):
 
     def __init__(self):
+        format = '[%(asctime)s] %(levelname)s:%(name)s:%(message)s'
+        datefmt = '%a %b %d %H:%M:%S %Y'
+        logging.basicConfig(level=logging.DEBUG, format=format,
+                datefmt=datefmt)
+
         CONFIG.parse()
-        from trytond.backend import Database
 
         if CONFIG['logfile']:
             logf = CONFIG['logfile']
@@ -45,7 +40,8 @@ class TrytonServer(object):
                     logf, 'D', 1, 30)
                 handler.rolloverAt -= diff
             except Exception, exception:
-                sys.stderr.write("ERROR: couldn't create the logfile directory:" \
+                sys.stderr.write(\
+                        "ERROR: couldn't create the logfile directory:" \
                         + str(exception))
             else:
                 formatter = logging.Formatter(format, datefmt)
@@ -75,7 +71,7 @@ class TrytonServer(object):
     def run(self):
         "Run the server and never return"
         from trytond.backend import Database
-        from pool import Pool
+        from trytond.pool import Pool
         from trytond.monitor import monitor
 
         update = False
@@ -151,13 +147,21 @@ class TrytonServer(object):
 
         # Launch Server
         if CONFIG['xmlrpc']:
-            from trytond.protocols.xmlrpc import HttpDaemon
-            httpd = HttpDaemon(CONFIG['interface'], CONFIG['xmlport'],
+            from trytond.protocols.xmlrpc import XMLRPCDaemon
+            xmlrpcd = XMLRPCDaemon(CONFIG['interface'], CONFIG['xmlport'],
                     CONFIG['secure_xmlrpc'])
             self.logger.info("starting XML-RPC%s protocol, port %d" % \
                     (CONFIG['secure_xmlrpc'] and ' Secure' or '',
                         CONFIG['xmlport']))
 
+        if CONFIG['jsonrpc']:
+            from trytond.protocols.jsonrpc import JSONRPCDaemon
+            jsonrpcd = JSONRPCDaemon(CONFIG['interface'], CONFIG['jsonport'],
+                    CONFIG['secure_jsonrpc'])
+            self.logger.info("starting JSON-RPC%s protocol, port %d" % \
+                    (CONFIG['secure_jsonrpc'] and ' Secure' or '',
+                        CONFIG['jsonport']))
+
         if CONFIG['netrpc']:
             from trytond.protocols.netrpc import NetRPCServerThread
             netrpcd = NetRPCServerThread(CONFIG['interface'], CONFIG['netport'],
@@ -182,7 +186,9 @@ class TrytonServer(object):
             if CONFIG['netrpc']:
                 netrpcd.stop()
             if CONFIG['xmlrpc']:
-                httpd.stop()
+                xmlrpcd.stop()
+            if CONFIG['jsonrpc']:
+                jsonrpcd.stop()
             if CONFIG['webdav']:
                 webdavd.stop()
             if CONFIG['pidfile']:
@@ -212,7 +218,9 @@ class TrytonServer(object):
         if CONFIG['netrpc']:
             netrpcd.start()
         if CONFIG['xmlrpc']:
-            httpd.start()
+            xmlrpcd.start()
+        if CONFIG['jsonrpc']:
+            jsonrpcd.start()
         if CONFIG['webdav']:
             webdavd.start()
 
