@@ -92,7 +92,7 @@ def install_module(name):
     databases = database.list(cursor)
     cursor.close()
     if DB_NAME not in databases:
-        create(DB_NAME, USER_PASSWORD, 'en_US', CONFIG['admin_passwd'])
+        create(DB_NAME, CONFIG['admin_passwd'], 'en_US', USER_PASSWORD)
     cursor = DB.cursor()
     module_obj = POOL.get('ir.module.module')
     module_ids = module_obj.search(cursor, USER, [
@@ -172,6 +172,8 @@ def all_suite():
     suite_.addTests(test_importdata.suite())
     import trytond.tests.test_exportdata as test_exportdata
     suite_.addTests(test_exportdata.suite())
+    import trytond.tests.test_protocols_datatype as test_protocols_datatype
+    suite_.addTests(test_protocols_datatype.suite())
     return suite_
 
 def modules_suite():
