@@ -5,6 +5,7 @@
     'name_de_DE': 'WebDAV',
     'name_es_ES': 'WebDAV',
     'name_fr_FR': 'WebDAV',
+    'name_ru_RU': 'WebDAV',
     'description': '''Basic module providing concept and administration of integrated WebDAV features.
 ''',
     'description_de_DE': '''Basismodul für Konzept und Administration der integrierten WebDAV-Komponente
@@ -12,6 +13,8 @@
     'description_es_ES': '''Módulo basico que provee el concepto y la administración de servicios WebDAV integrados.
 ''',
     'description_fr_FR': '''Module de base fournissant les concepts et l'administration des fonctionnalités integrées de WebDAV.
+''',
+    'description_ru_RU': '''Базовый модуль обеспечения и управления встроенными функциями WebDAV.
 ''',
     'active': True,
     'depends': ['ir'],
@@ -23,5 +26,6 @@
         'de_DE.csv',
         'es_ES.csv',
         'es_CO.csv',
+        'ru_RU.csv',
     ],
 }
