@@ -6,6 +6,7 @@ from trytond.model import ModelView, ModelSQL, fields
 from trytond.report import Report
 from trytond.tools import exec_command_pipe
 from trytond.backend import TableHandler
+from trytond.pyson import Eval, Equal, Not
 import expr
 import base64
 
@@ -67,14 +68,14 @@ class WorkflowActivity(ModelSQL, ModelView):
        ('stopall', 'Stop All'),
        ], 'Kind', required=True)
     action = fields.Text('Action', states={
-        'readonly': "kind == 'dummy'",
-        'required': "kind == 'function'",
+        'readonly': Equal(Eval('kind'), 'dummy'),
+        'required': Equal(Eval('kind'), 'function'),
         })
     flow_start = fields.Boolean('Flow Start')
     flow_stop = fields.Boolean('Flow Stop')
     subflow =  fields.Many2One('workflow', 'Subflow', states={
-        'readonly': "kind != 'subflow'",
-        'required': "kind == 'subflow'",
+        'readonly': Not(Equal(Eval('kind'), 'subflow')),
+        'required': Equal(Eval('kind'), 'subflow'),
         })
     signal_send = fields.Char('Signal (subflow.*)')
     out_transitions = fields.One2Many('workflow.transition', 'act_from',
@@ -119,7 +120,7 @@ class WorkflowTransition(ModelSQL, ModelView):
     act_to = fields.Many2One('workflow.activity', 'Destination Activity',
        required=True, select=1, ondelete='CASCADE')
     instances = fields.Many2Many('workflow.transition-workflow.instance',
-            'trans_id', 'inst_id')
+            'trans_id', 'inst_id', 'Instances')
 
     def default_condition(self, cursor, user, context=None):
         return 'True'
@@ -142,7 +143,7 @@ class WorkflowInstance(ModelSQL, ModelView):
     overflows = fields.One2Many('workflow.workitem', 'subflow',
             'Overflow')
     transitions = fields.Many2Many('workflow.transition-workflow.instance',
-            'inst_id', 'trans_id')
+            'inst_id', 'trans_id', 'Transitions')
     workitems = fields.One2Many('workflow.workitem', 'instance', 'Workitems')
 
     def __init__(self):
